==> bayonne2-0.9.2.tar.gz: bayonne2-0.9.2/binders/troll/checks.cpp <==
// Copyright (C) 2005 Open Source Telecom Corp.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include "module.h"

namespace binder {
using namespace ost;
using namespace std;

const char *Checks::chkAccept(Line *line, ScriptImage *img)
{
	Name *scr = img->getCurrent();
        unsigned idx = 0;
	const char *cp = scr->name;

        if(getMember(line))
                return "accept no members used";

        if(!useKeywords(line, "=timeout=id"))
                return "invalid keyword for accept";

	if(cp && !strnicmp(cp, "routing:", 8))
		return NULL;

	if(cp && !strnicmp(cp, "dialing:", 8))
		return NULL;

	return "accept only usable in routing or dialing"; 
}  

const char *Checks::chkCDR(Line *line, ScriptImage *img)
{
	char var[65];
	char *p;
	unsigned idx = 0;
	const char *cp;

	Name *scr = img->getCurrent();
	snprintf(var, sizeof(var), "cdr.%s", scr->name);
	p = strchr(var, ':');
	if(p)
		*p = 0;

	if(img->getPointer(var))
		return "cdr already assigned for this script file";

	if(getMember(line))
		return "cdr uses no members";

	if(hasKeywords(line))
		return "cdr has no keywords";

	while(NULL != (cp = getOption(line, &idx)))
	{
		if(!isalpha(*cp) && *cp != '%')
			return "invalid cdr entry used";
	}

	img->setPointer(var, line);
	return "";
}

const char *Checks::chkRegister(Line *line, ScriptImage *img)
{
	Name *scr = img->getCurrent();
	BayonneDriver *driver;
	char nbuf[32];
	char *p;

	if(scr->access != ScriptInterp::scrPUBLIC)
		return "cannot register non-public script";


	setString(nbuf, sizeof(nbuf), scr->name);
	p = strchr(nbuf, ':');
	if(p)
		*p = 0;
	else
		return "cannot use register in this context";

	driver = BayonneDriver::get(nbuf);
		
	if(!driver)
	{
		slog.warn("cannot register from %s", scr->name);
		return "";
	}
	return driver->registerScript(img, line);
}
	
} // end namespace

==> bayonne2-1.1.0.tar.gz: bayonne2-1.1.0/binders/troll/checks.cpp <==
// Copyright (C) 2005 Open Source Telecom Corp.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include "module.h"

namespace binder {
using namespace ost;
using namespace std;


const char *Checks::chkProtocol(Line *line, ScriptImage *img)       
{
        Name *scr = img->getCurrent();
        const char *cp = scr->name;
	unsigned idx = 0;

        if(strnicmp(cp, "routing:", 8))
                return "protocol selection only valid in routing.conf";  

	if(hasKeywords(line))
		return "protocol uses no keywords";

	cp = getMember(line);
	if(*cp == '.')
		++cp;

	if(!getOption(line, &idx))
		return "protocol has no entries";

	if(cp && !BayonneDriver::get(cp))
		return "";

	img->addSelect(line);
	return "";
}

const char *Checks::chkTrunking(Line *line, ScriptImage *img)
{
	Name *scr = img->getCurrent();
	const char *cp = scr->name;
	unsigned idx = 0;

	if(strnicmp(cp, "dialing:", 8))
		return "trunking selection only valid in dialing.conf";

	if(getMember(line))
		return "no options for select";

	if(!useKeywords(line, "=prefix=suffix"))
		return "invalid digit manipulation keywords";

	if(!getOption(line, &idx))
		return "no timeslot span entries for trunking";

	img->addSelect(line);
	return "";
}

const char *Checks::chkAccept(Line *line, ScriptImage *img)
{
	Name *scr = img->getCurrent();
        unsigned idx = 0;
	const char *cp = scr->name;

        if(getMember(line))
                return "accept no members used";

        if(!useKeywords(line, "=timeout=id"))
                return "invalid keyword for accept";

	if(cp && !strnicmp(cp, "routing:", 8))
		return NULL;

	if(cp && !strnicmp(cp, "dialing:", 8))
		return NULL;

	return "accept only usable in routing or dialing"; 
}  

const char *Checks::chkCDR(Line *line, ScriptImage *img)
{
	char var[65];
	char *p;
	unsigned idx = 0;
	const char *cp;

	Name *scr = img->getCurrent();
	snprintf(var, sizeof(var), "cdr.%s", scr->name);
	p = strchr(var, ':');
	if(p)
		*p = 0;

	if(img->getPointer(var))
		return "cdr already assigned for this script file";

	if(getMember(line))
		return "cdr uses no members";

	if(hasKeywords(line))
		return "cdr has no keywords";

	while(NULL != (cp = getOption(line, &idx)))
	{
		if(!isalpha(*cp) && *cp != '%')
			return "invalid cdr entry used";
	}

	img->setPointer(var, line);
	return "";
}

const char *Checks::chkConnect(Line *line, ScriptImage *img)
{
	unsigned idx = 0;

	if(getMember(line))
		return "no members for connecting";

	if(!useKeywords(line, "=limit=timeout=session=caller=display=timeout=duration"))
		return "invalid keyword for connecting";

	if(!getOption(line, &idx))
		return "no destination number for connecting";

	if(!getOption(line, &idx))
		return "no destination script for connecting";

	if(getOption(line, &idx))
		return "too many arguments for connecting";

	return NULL;
}
	
const char *Checks::chkRegister(Line *line, ScriptImage *img)
{
	Name *scr = img->getCurrent();
	BayonneDriver *driver;
	char nbuf[32];
	char *p;

	if(scr->access != ScriptInterp::scrPUBLIC)
		return "cannot register non-public script";


	setString(nbuf, sizeof(nbuf), scr->name);
	p = strchr(nbuf, ':');
	if(p)
		*p = 0;
	else
		return "cannot use register in this context";

	driver = BayonneDriver::get(nbuf);
		
	if(!driver)
	{
		slog.warn("cannot register from %s", scr->name);
		return "";
	}
	return driver->registerScript(img, line);
}
	
} // end namespace
